Class: Google::Apis::DeploymentmanagerAlpha::FirewallPolicyRuleOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::FirewallPolicyRuleOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Instance Attribute Summary collapse
-
#allocated_priority ⇒ Fixnum
The priority allocated for the firewall policy rule if query parameters specified minPriority/maxPriority.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleOperationMetadata
constructor
A new instance of FirewallPolicyRuleOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleOperationMetadata
Returns a new instance of FirewallPolicyRuleOperationMetadata.
1046 1047 1048 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_priority ⇒ Fixnum
The priority allocated for the firewall policy rule if query parameters
specified minPriority/maxPriority.
Corresponds to the JSON property allocatedPriority
1044 1045 1046 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1044 def allocated_priority @allocated_priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1051 1052 1053 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1051 def update!(**args) @allocated_priority = args[:allocated_priority] if args.key?(:allocated_priority) end |