Class: Google::Apis::DeploymentmanagerAlpha::Help

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Help

Returns a new instance of Help.



1134
1135
1136
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

URL(s) pointing to additional information on handling the current error. Corresponds to the JSON property links



1132
1133
1134
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1132

def links
  @links
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1139
1140
1141
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1139

def update!(**args)
  @links = args[:links] if args.key?(:links)
end