Class: Google::Apis::DeploymentmanagerAlpha::InputMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

InputMapping creates a 'virtual' property that will be injected into the properties before sending the request to the underlying API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InputMapping

Returns a new instance of InputMapping.



1265
1266
1267
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

The name of the field that is going to be injected. Corresponds to the JSON property fieldName

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1248

def field_name
  @field_name
end

#locationString

The location where this mapping applies. Corresponds to the JSON property location

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1253

def location
  @location
end

#method_matchString

Regex to evaluate on method to decide if input applies. Corresponds to the JSON property methodMatch

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1258

def method_match
  @method_match
end

#valueString

A jsonPath expression to select an element. Corresponds to the JSON property value

Returns:

  • (String)


1263
1264
1265
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1263

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1270
1271
1272
1273
1274
1275
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1270

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @location = args[:location] if args.key?(:location)
  @method_match = args[:method_match] if args.key?(:method_match)
  @value = args[:value] if args.key?(:value)
end