Class: Google::Apis::DeploymentmanagerAlpha::MethodMap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Deployment Manager will call these methods during the events of creation/ deletion/update/get/setIamPolicy

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodMap

Returns a new instance of MethodMap.



1417
1418
1419
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createString

The action identifier for the create method to be used for this collection Corresponds to the JSON property create

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1394

def create
  @create
end

#deleteString

The action identifier for the delete method to be used for this collection Corresponds to the JSON property delete

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1399

def delete
  @delete
end

#getString

The action identifier for the get method to be used for this collection Corresponds to the JSON property get

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1404

def get
  @get
end

#set_iam_policyString

The action identifier for the setIamPolicy method to be used for this collection Corresponds to the JSON property setIamPolicy

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1410

def set_iam_policy
  @set_iam_policy
end

#updateString

The action identifier for the update method to be used for this collection Corresponds to the JSON property update

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1415

def update
  @update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1422
1423
1424
1425
1426
1427
1428
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1422

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @delete = args[:delete] if args.key?(:delete)
  @get = args[:get] if args.key?(:get)
  @set_iam_policy = args[:set_iam_policy] if args.key?(:set_iam_policy)
  @update = args[:update] if args.key?(:update)
end