Class: Google::Apis::DeploymentmanagerAlpha::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



1670
1671
1672
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] The value of requestId if you provided it in the request. Not present otherwise. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1495

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Deprecated] This field is deprecated. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


1500
1501
1502
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1500

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


1506
1507
1508
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1506

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


1512
1513
1514
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1512

def end_time
  @end_time
end

#errorGoogle::Apis::DeploymentmanagerAlpha::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



1518
1519
1520
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1518

def error
  @error
end

#firewall_policy_rule_operation_metadataGoogle::Apis::DeploymentmanagerAlpha::FirewallPolicyRuleOperationMetadata

Corresponds to the JSON property firewallPolicyRuleOperationMetadata



1523
1524
1525
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1523

def 
  @firewall_policy_rule_operation_metadata
end

#get_version_operation_metadataGoogle::Apis::DeploymentmanagerAlpha::GetVersionOperationMetadata

Corresponds to the JSON property getVersionOperationMetadata



1528
1529
1530
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1528

def 
  @get_version_operation_metadata
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1534

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


1541
1542
1543
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1541

def http_error_status_code
  @http_error_status_code
end

#idFixnum

[Output Only] The unique identifier for the operation. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


1547
1548
1549
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1547

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


1553
1554
1555
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1553

def insert_time
  @insert_time
end

#instances_bulk_insert_operation_metadataGoogle::Apis::DeploymentmanagerAlpha::InstancesBulkInsertOperationMetadata

Corresponds to the JSON property instancesBulkInsertOperationMetadata



1558
1559
1560
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1558

def 
  @instances_bulk_insert_operation_metadata
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


1564
1565
1566
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1564

def kind
  @kind
end

#nameString

[Output Only] Name of the operation. Corresponds to the JSON property name

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1569

def name
  @name
end

#operation_group_idString

Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request. Corresponds to the JSON property operationGroupId

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1575

def operation_group_id
  @operation_group_id
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


1581
1582
1583
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1581

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


1589
1590
1591
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1589

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1595

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1600
1601
1602
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1600

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1606

def self_link_with_id
  @self_link_with_id
end

This field is used internally by the Autoscaler team and should not be promoted to "alpha/beta/v1". Corresponds to the JSON property setAutoscalerLinkOperationMetadata



1612
1613
1614
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1612

def 
  @set_autoscaler_link_operation_metadata
end

#set_common_instance_metadata_operation_metadataGoogle::Apis::DeploymentmanagerAlpha::SetCommonInstanceMetadataOperationMetadata

Output only. [Output Only] If the operation is for projects. setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state. Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata



1619
1620
1621
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1619

def 
  @set_common_instance_metadata_operation_metadata
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


1625
1626
1627
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1625

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


1631
1632
1633
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1631

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1637

def status_message
  @status_message
end

#target_idFixnum

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


1643
1644
1645
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1643

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1650

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: user@example.com or alice_smith_identifier (global/workforcePools/example-com-us-employees). Corresponds to the JSON property user

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1656

def user
  @user
end

#warningsArray<Google::Apis::DeploymentmanagerAlpha::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



1662
1663
1664
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1662

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1668

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1675

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @firewall_policy_rule_operation_metadata = args[:firewall_policy_rule_operation_metadata] if args.key?(:firewall_policy_rule_operation_metadata)
  @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @set_autoscaler_link_operation_metadata = args[:set_autoscaler_link_operation_metadata] if args.key?(:set_autoscaler_link_operation_metadata)
  @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end