Class: Google::Apis::DeploymentmanagerAlpha::Operation::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



1768
1769
1770
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<String>

Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE This is for internal use-only (like componentization) (thus the visibility " none") and in case of public exposure it is strongly recommended to follow pattern of: https://aip.dev/193 and expose as details field. Corresponds to the JSON property arguments

Returns:

  • (Array<String>)


1737
1738
1739
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1737

def arguments
  @arguments
end

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1742

def code
  @code
end

#debug_infoGoogle::Apis::DeploymentmanagerAlpha::DebugInfo

Describes additional debugging info. Corresponds to the JSON property debugInfo



1747
1748
1749
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1747

def debug_info
  @debug_info
end

#error_detailsArray<Google::Apis::DeploymentmanagerAlpha::Operation::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



1755
1756
1757
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1755

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


1761
1762
1763
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1761

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


1766
1767
1768
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1766

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1773
1774
1775
1776
1777
1778
1779
1780
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1773

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @code = args[:code] if args.key?(:code)
  @debug_info = args[:debug_info] if args.key?(:debug_info)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end