Class: Google::Apis::DeploymentmanagerAlpha::OperationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

A response containing a partial list of operations and a page token used to build the next request if the request has been truncated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationsListResponse

Returns a new instance of OperationsListResponse.



1912
1913
1914
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Output only. A token used to continue a truncated list request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1905
1906
1907
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1905

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DeploymentmanagerAlpha::Operation>

Output only. Operations contained in this list response. Corresponds to the JSON property operations



1910
1911
1912
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1910

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1917
1918
1919
1920
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1917

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
end