Class: Google::Apis::DeploymentmanagerAlpha::Options

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Options allows customized resource handling by Deployment Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Options

Returns a new instance of Options.



1949
1950
1951
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#async_optionsArray<Google::Apis::DeploymentmanagerAlpha::AsyncOptions>

Options regarding how to thread async requests. Corresponds to the JSON property asyncOptions



1930
1931
1932
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1930

def async_options
  @async_options
end

#input_mappingsArray<Google::Apis::DeploymentmanagerAlpha::InputMapping>

The mappings that apply for requests. Corresponds to the JSON property inputMappings



1935
1936
1937
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1935

def input_mappings
  @input_mappings
end

#name_propertyString

The json path to the field in the resource JSON body into which the resource name should be mapped. Leaving this empty indicates that there should be no mapping performed. Corresponds to the JSON property nameProperty

Returns:

  • (String)


1942
1943
1944
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1942

def name_property
  @name_property
end

#validation_optionsGoogle::Apis::DeploymentmanagerAlpha::ValidationOptions

Options for how to validate and process properties on a resource. Corresponds to the JSON property validationOptions



1947
1948
1949
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1947

def validation_options
  @validation_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1954
1955
1956
1957
1958
1959
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1954

def update!(**args)
  @async_options = args[:async_options] if args.key?(:async_options)
  @input_mappings = args[:input_mappings] if args.key?(:input_mappings)
  @name_property = args[:name_property] if args.key?(:name_property)
  @validation_options = args[:validation_options] if args.key?(:validation_options)
end