Class: Google::Apis::DeploymentmanagerAlpha::PollingOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PollingOptions

Returns a new instance of PollingOptions.



2036
2037
2038
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#diagnosticsArray<Google::Apis::DeploymentmanagerAlpha::Diagnostic>

An array of diagnostics to be collected by Deployment Manager, these diagnostics will be displayed to the user. Corresponds to the JSON property diagnostics



2013
2014
2015
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2013

def diagnostics
  @diagnostics
end

#fail_conditionString

JsonPath expression that determines if the request failed. Corresponds to the JSON property failCondition

Returns:

  • (String)


2018
2019
2020
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2018

def fail_condition
  @fail_condition
end

#finish_conditionString

JsonPath expression that determines if the request is completed. Corresponds to the JSON property finishCondition

Returns:

  • (String)


2023
2024
2025
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2023

def finish_condition
  @finish_condition
end

JsonPath expression that evaluates to string, it indicates where to poll. Corresponds to the JSON property pollingLink

Returns:

  • (String)


2028
2029
2030
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2028

def polling_link
  @polling_link
end

JsonPath expression, after polling is completed, indicates where to fetch the resource. Corresponds to the JSON property targetLink

Returns:

  • (String)


2034
2035
2036
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2034

def target_link
  @target_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2041
2042
2043
2044
2045
2046
2047
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2041

def update!(**args)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @fail_condition = args[:fail_condition] if args.key?(:fail_condition)
  @finish_condition = args[:finish_condition] if args.key?(:finish_condition)
  @polling_link = args[:polling_link] if args.key?(:polling_link)
  @target_link = args[:target_link] if args.key?(:target_link)
end