Class: Google::Apis::DeploymentmanagerAlpha::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Additional details for quota exceeded error for resource quota.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaExceededInfo

Returns a new instance of QuotaExceededInfo.



2138
2139
2140
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsHash<String,String>

The map holding related quota dimensions. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


2109
2110
2111
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2109

def dimensions
  @dimensions
end

#future_limitFloat

Future quota limit being rolled out. The limit's unit depends on the quota type or metric. Corresponds to the JSON property futureLimit

Returns:

  • (Float)


2115
2116
2117
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2115

def future_limit
  @future_limit
end

#limitFloat

Current effective quota limit. The limit's unit depends on the quota type or metric. Corresponds to the JSON property limit

Returns:

  • (Float)


2121
2122
2123
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2121

def limit
  @limit
end

#limit_nameString

The name of the quota limit. Corresponds to the JSON property limitName

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2126

def limit_name
  @limit_name
end

#metric_nameString

The Compute Engine quota metric name. Corresponds to the JSON property metricName

Returns:

  • (String)


2131
2132
2133
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2131

def metric_name
  @metric_name
end

#rollout_statusString

Rollout status of the future quota limit. Corresponds to the JSON property rolloutStatus

Returns:

  • (String)


2136
2137
2138
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2136

def rollout_status
  @rollout_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2143
2144
2145
2146
2147
2148
2149
2150
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2143

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @future_limit = args[:future_limit] if args.key?(:future_limit)
  @limit = args[:limit] if args.key?(:limit)
  @limit_name = args[:limit_name] if args.key?(:limit_name)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @rollout_status = args[:rollout_status] if args.key?(:rollout_status)
end