Class: Google::Apis::DeploymentmanagerAlpha::ResourceUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceUpdate

Returns a new instance of ResourceUpdate.



2402
2403
2404
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_controlGoogle::Apis::DeploymentmanagerAlpha::ResourceAccessControl

The access controls set on the resource. Corresponds to the JSON property accessControl



2348
2349
2350
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2348

def access_control
  @access_control
end

#credentialGoogle::Apis::DeploymentmanagerAlpha::Credential

The credential used by Deployment Manager and TypeProvider. Only one of the options is permitted. Corresponds to the JSON property credential



2354
2355
2356
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2354

def credential
  @credential
end

#errorGoogle::Apis::DeploymentmanagerAlpha::ResourceUpdate::Error

Output only. If errors are generated during update of the resource, this field will be populated. Corresponds to the JSON property error



2360
2361
2362
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2360

def error
  @error
end

#final_propertiesString

Output only. The expanded properties of the resource with reference values expanded. Returned as serialized YAML. Corresponds to the JSON property finalProperties

Returns:

  • (String)


2366
2367
2368
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2366

def final_properties
  @final_properties
end

#intentString

Output only. The intent of the resource: PREVIEW, UPDATE, or CANCEL. Corresponds to the JSON property intent

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2371

def intent
  @intent
end

#manifestString

Output only. URL of the manifest representing the update configuration of this resource. Corresponds to the JSON property manifest

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2377

def manifest
  @manifest
end

#propertiesString

Output only. The set of updated properties for this resource, before references are expanded. Returned as serialized YAML. Corresponds to the JSON property properties

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2383

def properties
  @properties
end

#runtime_policiesArray<String>

Output only. In case this is an action, it will show the runtimePolicies that this action will have after updating the deployment. Corresponds to the JSON property runtimePolicies

Returns:

  • (Array<String>)


2389
2390
2391
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2389

def runtime_policies
  @runtime_policies
end

#stateString

Output only. The state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


2394
2395
2396
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2394

def state
  @state
end

#warningsArray<Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Warning>

Output only. If warning messages are generated during processing of this resource, this field will be populated. Corresponds to the JSON property warnings



2400
2401
2402
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2400

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2407

def update!(**args)
  @access_control = args[:access_control] if args.key?(:access_control)
  @credential = args[:credential] if args.key?(:credential)
  @error = args[:error] if args.key?(:error)
  @final_properties = args[:final_properties] if args.key?(:final_properties)
  @intent = args[:intent] if args.key?(:intent)
  @manifest = args[:manifest] if args.key?(:manifest)
  @properties = args[:properties] if args.key?(:properties)
  @runtime_policies = args[:runtime_policies] if args.key?(:runtime_policies)
  @state = args[:state] if args.key?(:state)
  @warnings = args[:warnings] if args.key?(:warnings)
end