Class: Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



2428
2429
2430
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<String>

Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE This is for internal use-only (like componentization) (thus the visibility " none") and in case of public exposure it is strongly recommended to follow pattern of: https://aip.dev/193 and expose as details field. Corresponds to the JSON property arguments

Returns:

  • (Array<String>)


2397
2398
2399
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2397

def arguments
  @arguments
end

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


2402
2403
2404
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2402

def code
  @code
end

#debug_infoGoogle::Apis::DeploymentmanagerAlpha::DebugInfo

Describes additional debugging info. Corresponds to the JSON property debugInfo



2407
2408
2409
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2407

def debug_info
  @debug_info
end

#error_detailsArray<Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



2415
2416
2417
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2415

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


2421
2422
2423
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2421

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2426

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2433
2434
2435
2436
2437
2438
2439
2440
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2433

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @code = args[:code] if args.key?(:code)
  @debug_info = args[:debug_info] if args.key?(:debug_info)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end