Class: Google::Apis::DeploymentmanagerAlpha::TypeInfoSchemaInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TypeInfoSchemaInfo

Returns a new instance of TypeInfoSchemaInfo.



2985
2986
2987
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inputString

The properties that this composite type or base type collection accept as input, represented as a json blob, format is: JSON Schema Draft V4 Corresponds to the JSON property input

Returns:

  • (String)


2976
2977
2978
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2976

def input
  @input
end

#outputString

The properties that this composite type or base type collection exposes as output, these properties can be used for references, represented as json blob, format is: JSON Schema Draft V4 Corresponds to the JSON property output

Returns:

  • (String)


2983
2984
2985
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2983

def output
  @output
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2990
2991
2992
2993
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2990

def update!(**args)
  @input = args[:input] if args.key?(:input)
  @output = args[:output] if args.key?(:output)
end