Class: Google::Apis::DeploymentmanagerAlpha::Options
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::Options
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Overview
Options allows customized resource handling by Deployment Manager.
Instance Attribute Summary collapse
-
#async_options ⇒ Array<Google::Apis::DeploymentmanagerAlpha::AsyncOptions>
Options regarding how to thread async requests.
-
#input_mappings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::InputMapping>
The mappings that apply for requests.
-
#name_property ⇒ String
The json path to the field in the resource JSON body into which the resource name should be mapped.
-
#validation_options ⇒ Google::Apis::DeploymentmanagerAlpha::ValidationOptions
Options for how to validate and process properties on a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Options
constructor
A new instance of Options.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Options
Returns a new instance of Options.
1897 1898 1899 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#async_options ⇒ Array<Google::Apis::DeploymentmanagerAlpha::AsyncOptions>
Options regarding how to thread async requests.
Corresponds to the JSON property asyncOptions
1878 1879 1880 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1878 def @async_options end |
#input_mappings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::InputMapping>
The mappings that apply for requests.
Corresponds to the JSON property inputMappings
1883 1884 1885 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1883 def input_mappings @input_mappings end |
#name_property ⇒ String
The json path to the field in the resource JSON body into which the resource
name should be mapped. Leaving this empty indicates that there should be no
mapping performed.
Corresponds to the JSON property nameProperty
1890 1891 1892 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1890 def name_property @name_property end |
#validation_options ⇒ Google::Apis::DeploymentmanagerAlpha::ValidationOptions
Options for how to validate and process properties on a resource.
Corresponds to the JSON property validationOptions
1895 1896 1897 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1895 def @validation_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1902 1903 1904 1905 1906 1907 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 1902 def update!(**args) @async_options = args[:async_options] if args.key?(:async_options) @input_mappings = args[:input_mappings] if args.key?(:input_mappings) @name_property = args[:name_property] if args.key?(:name_property) @validation_options = args[:validation_options] if args.key?(:validation_options) end |