Class: Google::Apis::DeploymentmanagerAlpha::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Additional details for quota exceeded error for resource quota.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaExceededInfo

Returns a new instance of QuotaExceededInfo.



2086
2087
2088
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsHash<String,String>

The map holding related quota dimensions. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


2057
2058
2059
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2057

def dimensions
  @dimensions
end

#future_limitFloat

Future quota limit being rolled out. The limit's unit depends on the quota type or metric. Corresponds to the JSON property futureLimit

Returns:

  • (Float)


2063
2064
2065
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2063

def future_limit
  @future_limit
end

#limitFloat

Current effective quota limit. The limit's unit depends on the quota type or metric. Corresponds to the JSON property limit

Returns:

  • (Float)


2069
2070
2071
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2069

def limit
  @limit
end

#limit_nameString

The name of the quota limit. Corresponds to the JSON property limitName

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2074

def limit_name
  @limit_name
end

#metric_nameString

The Compute Engine quota metric name. Corresponds to the JSON property metricName

Returns:

  • (String)


2079
2080
2081
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2079

def metric_name
  @metric_name
end

#rollout_statusString

Rollout status of the future quota limit. Corresponds to the JSON property rolloutStatus

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2084

def rollout_status
  @rollout_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2091
2092
2093
2094
2095
2096
2097
2098
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2091

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @future_limit = args[:future_limit] if args.key?(:future_limit)
  @limit = args[:limit] if args.key?(:limit)
  @limit_name = args[:limit_name] if args.key?(:limit_name)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @rollout_status = args[:rollout_status] if args.key?(:rollout_status)
end