Class: Google::Apis::DeploymentmanagerAlpha::Resource
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceAccessControl
The access controls set on the resource.
-
#final_properties ⇒ String
Output only.
-
#id ⇒ Fixnum
Corresponds to the JSON property
id. -
#insert_time ⇒ String
Output only.
-
#last_used_credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider.
-
#manifest ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#properties ⇒ String
Output only.
-
#runtime_policies ⇒ Array<String>
Output only.
-
#type ⇒ String
Output only.
-
#update ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceUpdate
Output only.
-
#update_time ⇒ String
Output only.
-
#url ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::Resource::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
2235 2236 2237 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceAccessControl
The access controls set on the resource.
Corresponds to the JSON property accessControl
2160 2161 2162 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2160 def access_control @access_control end |
#final_properties ⇒ String
Output only. The evaluated properties of the resource with references expanded.
Returned as serialized YAML.
Corresponds to the JSON property finalProperties
2166 2167 2168 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2166 def final_properties @final_properties end |
#id ⇒ Fixnum
Corresponds to the JSON property id
2171 2172 2173 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2171 def id @id end |
#insert_time ⇒ String
Output only. Creation timestamp in RFC3339 text format.
Corresponds to the JSON property insertTime
2176 2177 2178 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2176 def insert_time @insert_time end |
#last_used_credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider. Only one of the
options is permitted.
Corresponds to the JSON property lastUsedCredential
2182 2183 2184 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2182 def last_used_credential @last_used_credential end |
#manifest ⇒ String
Output only. URL of the manifest representing the current configuration of
this resource.
Corresponds to the JSON property manifest
2188 2189 2190 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2188 def manifest @manifest end |
#name ⇒ String
Output only. The name of the resource as it appears in the YAML config.
Corresponds to the JSON property name
2193 2194 2195 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2193 def name @name end |
#properties ⇒ String
Output only. The current properties of the resource before any references have
been filled in. Returned as serialized YAML.
Corresponds to the JSON property properties
2199 2200 2201 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2199 def properties @properties end |
#runtime_policies ⇒ Array<String>
Output only. In case this is an action, it will show the runtimePolicies on
which this action will run in the deployment
Corresponds to the JSON property runtimePolicies
2205 2206 2207 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2205 def runtime_policies @runtime_policies end |
#type ⇒ String
Output only. The type of the resource, for example compute.v1.instance, or
cloudfunctions.v1beta1.function.
Corresponds to the JSON property type
2211 2212 2213 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2211 def type @type end |
#update ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceUpdate
Output only. If Deployment Manager is currently updating or previewing an
update to this resource, the updated configuration appears here.
Corresponds to the JSON property update
2217 2218 2219 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2217 def update @update end |
#update_time ⇒ String
Output only. Update timestamp in RFC3339 text format.
Corresponds to the JSON property updateTime
2222 2223 2224 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2222 def update_time @update_time end |
#url ⇒ String
Output only. The URL of the actual resource.
Corresponds to the JSON property url
2227 2228 2229 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2227 def url @url end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::Resource::Warning>
Output only. If warning messages are generated during processing of this
resource, this field will be populated.
Corresponds to the JSON property warnings
2233 2234 2235 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2233 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2240 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @final_properties = args[:final_properties] if args.key?(:final_properties) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @last_used_credential = args[:last_used_credential] if args.key?(:last_used_credential) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) @runtime_policies = args[:runtime_policies] if args.key?(:runtime_policies) @type = args[:type] if args.key?(:type) @update = args[:update] if args.key?(:update) @update_time = args[:update_time] if args.key?(:update_time) @url = args[:url] if args.key?(:url) @warnings = args[:warnings] if args.key?(:warnings) end |