Class: Google::Apis::DeploymentmanagerAlpha::ResourceUpdate
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::ResourceUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceAccessControl
The access controls set on the resource.
-
#credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider.
-
#error ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Error
Output only.
-
#final_properties ⇒ String
Output only.
-
#intent ⇒ String
Output only.
-
#manifest ⇒ String
Output only.
-
#properties ⇒ String
Output only.
-
#runtime_policies ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceUpdate
constructor
A new instance of ResourceUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceUpdate
Returns a new instance of ResourceUpdate.
2350 2351 2352 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceAccessControl
The access controls set on the resource.
Corresponds to the JSON property accessControl
2296 2297 2298 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2296 def access_control @access_control end |
#credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider. Only one of the
options is permitted.
Corresponds to the JSON property credential
2302 2303 2304 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2302 def credential @credential end |
#error ⇒ Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Error
Output only. If errors are generated during update of the resource, this field
will be populated.
Corresponds to the JSON property error
2308 2309 2310 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2308 def error @error end |
#final_properties ⇒ String
Output only. The expanded properties of the resource with reference values
expanded. Returned as serialized YAML.
Corresponds to the JSON property finalProperties
2314 2315 2316 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2314 def final_properties @final_properties end |
#intent ⇒ String
Output only. The intent of the resource: PREVIEW, UPDATE, or CANCEL.
Corresponds to the JSON property intent
2319 2320 2321 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2319 def intent @intent end |
#manifest ⇒ String
Output only. URL of the manifest representing the update configuration of this
resource.
Corresponds to the JSON property manifest
2325 2326 2327 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2325 def manifest @manifest end |
#properties ⇒ String
Output only. The set of updated properties for this resource, before
references are expanded. Returned as serialized YAML.
Corresponds to the JSON property properties
2331 2332 2333 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2331 def properties @properties end |
#runtime_policies ⇒ Array<String>
Output only. In case this is an action, it will show the runtimePolicies that
this action will have after updating the deployment.
Corresponds to the JSON property runtimePolicies
2337 2338 2339 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2337 def runtime_policies @runtime_policies end |
#state ⇒ String
Output only. The state of the resource.
Corresponds to the JSON property state
2342 2343 2344 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2342 def state @state end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerAlpha::ResourceUpdate::Warning>
Output only. If warning messages are generated during processing of this
resource, this field will be populated.
Corresponds to the JSON property warnings
2348 2349 2350 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2348 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2355 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @credential = args[:credential] if args.key?(:credential) @error = args[:error] if args.key?(:error) @final_properties = args[:final_properties] if args.key?(:final_properties) @intent = args[:intent] if args.key?(:intent) @manifest = args[:manifest] if args.key?(:manifest) @properties = args[:properties] if args.key?(:properties) @runtime_policies = args[:runtime_policies] if args.key?(:runtime_policies) @state = args[:state] if args.key?(:state) @warnings = args[:warnings] if args.key?(:warnings) end |