Class: Google::Apis::DeploymentmanagerAlpha::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::DeploymentmanagerAlpha::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
2674 2675 2676 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::DeploymentmanagerAlpha::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2666 2667 2668 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2666 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
2672 2673 2674 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2672 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2679 2680 2681 2682 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2679 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |