Class: Google::Apis::DeploymentmanagerAlpha::TypeInfo
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::TypeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Overview
Type Information. Contains detailed information about a composite type, base type, or base type with specific collection.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the type.
-
#documentation_link ⇒ String
For swagger 2.0 externalDocs field will be used.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The base type or composite type name.
-
#schema ⇒ Google::Apis::DeploymentmanagerAlpha::TypeInfoSchemaInfo
For base types with a collection, we return a schema and documentation link For template types, we return only a schema Corresponds to the JSON property
schema. -
#self_link ⇒ String
Output only.
-
#title ⇒ String
The title on the API descriptor URL provided.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TypeInfo
constructor
A new instance of TypeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TypeInfo
Returns a new instance of TypeInfo.
3004 3005 3006 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the type.
Corresponds to the JSON property description
2969 2970 2971 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2969 def description @description end |
#documentation_link ⇒ String
For swagger 2.0 externalDocs field will be used. For swagger 1.2 this field
will be empty.
Corresponds to the JSON property documentationLink
2975 2976 2977 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2975 def documentation_link @documentation_link end |
#kind ⇒ String
Output only. Type of the output. Always deploymentManager#TypeInfo for
TypeInfo.
Corresponds to the JSON property kind
2981 2982 2983 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2981 def kind @kind end |
#name ⇒ String
The base type or composite type name.
Corresponds to the JSON property name
2986 2987 2988 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2986 def name @name end |
#schema ⇒ Google::Apis::DeploymentmanagerAlpha::TypeInfoSchemaInfo
For base types with a collection, we return a schema and documentation link
For template types, we return only a schema
Corresponds to the JSON property schema
2992 2993 2994 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2992 def schema @schema end |
#self_link ⇒ String
Output only. Self link for the type provider.
Corresponds to the JSON property selfLink
2997 2998 2999 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2997 def self_link @self_link end |
#title ⇒ String
The title on the API descriptor URL provided.
Corresponds to the JSON property title
3002 3003 3004 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3002 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3009 def update!(**args) @description = args[:description] if args.key?(:description) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) @self_link = args[:self_link] if args.key?(:self_link) @title = args[:title] if args.key?(:title) end |