Class: Google::Apis::DeploymentmanagerAlpha::TypeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

Type Information. Contains detailed information about a composite type, base type, or base type with specific collection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TypeInfo

Returns a new instance of TypeInfo.



2952
2953
2954
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the type. Corresponds to the JSON property description

Returns:

  • (String)


2917
2918
2919
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2917

def description
  @description
end

For swagger 2.0 externalDocs field will be used. For swagger 1.2 this field will be empty. Corresponds to the JSON property documentationLink

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2923

def documentation_link
  @documentation_link
end

#kindString

Output only. Type of the output. Always deploymentManager#TypeInfo for TypeInfo. Corresponds to the JSON property kind

Returns:

  • (String)


2929
2930
2931
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2929

def kind
  @kind
end

#nameString

The base type or composite type name. Corresponds to the JSON property name

Returns:

  • (String)


2934
2935
2936
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2934

def name
  @name
end

#schemaGoogle::Apis::DeploymentmanagerAlpha::TypeInfoSchemaInfo

For base types with a collection, we return a schema and documentation link For template types, we return only a schema Corresponds to the JSON property schema



2940
2941
2942
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2940

def schema
  @schema
end

Output only. Self link for the type provider. Corresponds to the JSON property selfLink

Returns:

  • (String)


2945
2946
2947
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2945

def self_link
  @self_link
end

#titleString

The title on the API descriptor URL provided. Corresponds to the JSON property title

Returns:

  • (String)


2950
2951
2952
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2950

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 2957

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @self_link = args[:self_link] if args.key?(:self_link)
  @title = args[:title] if args.key?(:title)
end