Class: Google::Apis::DeploymentmanagerAlpha::TypeProvider
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerAlpha::TypeProvider
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb
Overview
A type provider that describes a service-backed Type.
Instance Attribute Summary collapse
-
#collection_overrides ⇒ Array<Google::Apis::DeploymentmanagerAlpha::CollectionOverride>
Allows resource handling overrides for specific collections Corresponds to the JSON property
collectionOverrides. -
#credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider.
-
#custom_certificate_authority_roots ⇒ Array<String>
List of up to 2 custom certificate authority roots to use for TLS authentication when making calls on behalf of this type provider.
-
#description ⇒ String
An optional textual description of the resource; provided by the client when the resource is created.
-
#descriptor_url ⇒ String
Descriptor Url for the this type provider.
-
#id ⇒ Fixnum
Output only.
-
#insert_time ⇒ String
Output only.
-
#labels ⇒ Array<Google::Apis::DeploymentmanagerAlpha::TypeProviderLabelEntry>
Map of One Platform labels; provided by the client when the resource is created or updated.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#operation ⇒ Google::Apis::DeploymentmanagerAlpha::Operation
Represents an Operation resource.
-
#options ⇒ Google::Apis::DeploymentmanagerAlpha::Options
Options allows customized resource handling by Deployment Manager.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TypeProvider
constructor
A new instance of TypeProvider.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TypeProvider
Returns a new instance of TypeProvider.
3163 3164 3165 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_overrides ⇒ Array<Google::Apis::DeploymentmanagerAlpha::CollectionOverride>
Allows resource handling overrides for specific collections
Corresponds to the JSON property collectionOverrides
3080 3081 3082 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3080 def collection_overrides @collection_overrides end |
#credential ⇒ Google::Apis::DeploymentmanagerAlpha::Credential
The credential used by Deployment Manager and TypeProvider. Only one of the
options is permitted.
Corresponds to the JSON property credential
3086 3087 3088 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3086 def credential @credential end |
#custom_certificate_authority_roots ⇒ Array<String>
List of up to 2 custom certificate authority roots to use for TLS
authentication when making calls on behalf of this type provider. If set, TLS
authentication will exclusively use these roots instead of relying on publicly
trusted certificate authorities when validating TLS certificate authenticity.
The certificates must be in base64-encoded PEM format. The maximum size of
each certificate must not exceed 10KB.
Corresponds to the JSON property customCertificateAuthorityRoots
3096 3097 3098 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3096 def @custom_certificate_authority_roots end |
#description ⇒ String
An optional textual description of the resource; provided by the client when
the resource is created.
Corresponds to the JSON property description
3102 3103 3104 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3102 def description @description end |
#descriptor_url ⇒ String
Descriptor Url for the this type provider.
Corresponds to the JSON property descriptorUrl
3107 3108 3109 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3107 def descriptor_url @descriptor_url end |
#id ⇒ Fixnum
Output only. Unique identifier for the resource defined by the server.
Corresponds to the JSON property id
3112 3113 3114 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3112 def id @id end |
#insert_time ⇒ String
Output only. Creation timestamp in RFC3339 text format.
Corresponds to the JSON property insertTime
3117 3118 3119 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3117 def insert_time @insert_time end |
#labels ⇒ Array<Google::Apis::DeploymentmanagerAlpha::TypeProviderLabelEntry>
Map of One Platform labels; provided by the client when the resource is
created or updated. Specifically: Label keys must be between 1 and 63
characters long and must conform to the following regular expression: [a-z]([-
a-z0-9]*[a-z0-9])? Label values must be between 0 and 63 characters long and
must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?
Corresponds to the JSON property labels
3126 3127 3128 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3126 def labels @labels end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
3136 3137 3138 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3136 def name @name end |
#operation ⇒ Google::Apis::DeploymentmanagerAlpha::Operation
Represents an Operation resource. Google Compute Engine has three Operation
resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API
requests. For more information, read Handling API responses. Operations can be
global, regional or zonal. - For global operations, use the globalOperations
resource. - For regional operations, use the regionOperations resource. -
For zonal operations, use the zoneOperations resource. For more information,
read Global, Regional, and Zonal Resources. Note that completed Operation
resources have a limited retention period.
Corresponds to the JSON property operation
3151 3152 3153 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3151 def operation @operation end |
#options ⇒ Google::Apis::DeploymentmanagerAlpha::Options
Options allows customized resource handling by Deployment Manager.
Corresponds to the JSON property options
3156 3157 3158 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3156 def @options end |
#self_link ⇒ String
Output only. Self link for the type provider.
Corresponds to the JSON property selfLink
3161 3162 3163 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3161 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3168 def update!(**args) @collection_overrides = args[:collection_overrides] if args.key?(:collection_overrides) @credential = args[:credential] if args.key?(:credential) @custom_certificate_authority_roots = args[:custom_certificate_authority_roots] if args.key?(:custom_certificate_authority_roots) @description = args[:description] if args.key?(:description) @descriptor_url = args[:descriptor_url] if args.key?(:descriptor_url) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) @options = args[:options] if args.key?(:options) @self_link = args[:self_link] if args.key?(:self_link) end |