Class: Google::Apis::DeploymentmanagerAlpha::TypeProvider

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_alpha/classes.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb,
lib/google/apis/deploymentmanager_alpha/representations.rb

Overview

A type provider that describes a service-backed Type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TypeProvider

Returns a new instance of TypeProvider.



3111
3112
3113
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_overridesArray<Google::Apis::DeploymentmanagerAlpha::CollectionOverride>

Allows resource handling overrides for specific collections Corresponds to the JSON property collectionOverrides



3028
3029
3030
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3028

def collection_overrides
  @collection_overrides
end

#credentialGoogle::Apis::DeploymentmanagerAlpha::Credential

The credential used by Deployment Manager and TypeProvider. Only one of the options is permitted. Corresponds to the JSON property credential



3034
3035
3036
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3034

def credential
  @credential
end

#custom_certificate_authority_rootsArray<String>

List of up to 2 custom certificate authority roots to use for TLS authentication when making calls on behalf of this type provider. If set, TLS authentication will exclusively use these roots instead of relying on publicly trusted certificate authorities when validating TLS certificate authenticity. The certificates must be in base64-encoded PEM format. The maximum size of each certificate must not exceed 10KB. Corresponds to the JSON property customCertificateAuthorityRoots

Returns:

  • (Array<String>)


3044
3045
3046
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3044

def custom_certificate_authority_roots
  @custom_certificate_authority_roots
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


3050
3051
3052
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3050

def description
  @description
end

#descriptor_urlString

Descriptor Url for the this type provider. Corresponds to the JSON property descriptorUrl

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3055

def descriptor_url
  @descriptor_url
end

#idFixnum

Output only. Unique identifier for the resource defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


3060
3061
3062
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3060

def id
  @id
end

#insert_timeString

Output only. Creation timestamp in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


3065
3066
3067
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3065

def insert_time
  @insert_time
end

#labelsArray<Google::Apis::DeploymentmanagerAlpha::TypeProviderLabelEntry>

Map of One Platform labels; provided by the client when the resource is created or updated. Specifically: Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([- a-z0-9]*[a-z0-9])? Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)? Corresponds to the JSON property labels



3074
3075
3076
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3074

def labels
  @labels
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3084

def name
  @name
end

#operationGoogle::Apis::DeploymentmanagerAlpha::Operation

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period. Corresponds to the JSON property operation



3099
3100
3101
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3099

def operation
  @operation
end

#optionsGoogle::Apis::DeploymentmanagerAlpha::Options

Options allows customized resource handling by Deployment Manager. Corresponds to the JSON property options



3104
3105
3106
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3104

def options
  @options
end

Output only. Self link for the type provider. Corresponds to the JSON property selfLink

Returns:

  • (String)


3109
3110
3111
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3109

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
# File 'lib/google/apis/deploymentmanager_alpha/classes.rb', line 3116

def update!(**args)
  @collection_overrides = args[:collection_overrides] if args.key?(:collection_overrides)
  @credential = args[:credential] if args.key?(:credential)
  @custom_certificate_authority_roots = args[:custom_certificate_authority_roots] if args.key?(:custom_certificate_authority_roots)
  @description = args[:description] if args.key?(:description)
  @descriptor_url = args[:descriptor_url] if args.key?(:descriptor_url)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @options = args[:options] if args.key?(:options)
  @self_link = args[:self_link] if args.key?(:self_link)
end